"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = require("./get-log");

const MAX_DISCONNECT_TIME = 10000;

const dispose = async pool => {
  if (pool.connection != null) {
    const log = (0, _getLog.getLog)('dispose');
    const extraClient = pool.extraConnections.values();
    pool.extraConnections.clear(); //TODO: Promise.allSettled

    for (const client of extraClient) {
      try {
        await client.end();
      } catch (error) {
        log.error(`Could not end extra client connection: ${error}`);
      }
    } //TODO: Promise.allSettled


    const loaders = pool.eventLoaders.values();

    for (const loader of loaders) {
      await loader.close();
    }

    const connection = pool.connection;
    pool.connection = undefined;
    let timeout = null;

    try {
      await Promise.race([new Promise(resolve => {
        timeout = setTimeout(resolve, MAX_DISCONNECT_TIME);
      }), connection.end()]);
    } catch (err) {
      log.error(err);
    } finally {
      if (timeout != null) {
        clearTimeout(timeout);
      }
    }
  }
};

var _default = dispose;
exports.default = _default;
//# sourceMappingURL=dispose.js.map